# Egobox

## Surrogate-based adaptative optimization: _Egor_

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/relf/egobox/blob/master/doc/Egor_Tutorial.ipynb)

## Mixture of Gaussian process surrogates: _Gpx_

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/relf/egobox/blob/master/doc/Gpx_Tutorial.ipynb)

## Gaussian process surrogates: _SparseGpx_

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/relf/egobox/blob/master/doc/SparseGpx_Tutorial.ipynb)

## _Gpx_ on Mauna Loa CO2 data

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/relf/egobox/blob/master/doc/Gpx_MaunaLoaCO2.ipynb)
